@@ -25,7 +25,7 @@
 
 #define TABLE_SIZE x
 
-template <typename T>
+template<typename T>
 struct StringValueTable {
     const char *name;
     typename T::type value;
@@ -46,19 +46,19 @@ static const StringValueTable<MailTransport::Transport::EnumEncryption> encrypti
 static const int encryptionEnumSize = sizeof(encryptionEnum) / sizeof(*encryptionEnum);
 
 static const StringValueTable<MailTransport::Transport::EnumAuthenticationType> authenticationTypeEnum[] = {
-    { "login",      MailTransport::Transport::EnumAuthenticationType::LOGIN },
-    { "plain",      MailTransport::Transport::EnumAuthenticationType::PLAIN },
-    { "cram-md5",   MailTransport::Transport::EnumAuthenticationType::CRAM_MD5 },
+    { "login", MailTransport::Transport::EnumAuthenticationType::LOGIN },
+    { "plain", MailTransport::Transport::EnumAuthenticationType::PLAIN },
+    { "cram-md5", MailTransport::Transport::EnumAuthenticationType::CRAM_MD5 },
     { "digest-md5", MailTransport::Transport::EnumAuthenticationType::DIGEST_MD5 },
-    { "gssapi",     MailTransport::Transport::EnumAuthenticationType::GSSAPI },
-    { "ntlm",       MailTransport::Transport::EnumAuthenticationType::NTLM },
-    { "apop",       MailTransport::Transport::EnumAuthenticationType::APOP },
-    { "clear",      MailTransport::Transport::EnumAuthenticationType::CLEAR },
-    { "anonymous",  MailTransport::Transport::EnumAuthenticationType::ANONYMOUS }
+    { "gssapi", MailTransport::Transport::EnumAuthenticationType::GSSAPI },
+    { "ntlm", MailTransport::Transport::EnumAuthenticationType::NTLM },
+    { "apop", MailTransport::Transport::EnumAuthenticationType::APOP },
+    { "clear", MailTransport::Transport::EnumAuthenticationType::CLEAR },
+    { "anonymous", MailTransport::Transport::EnumAuthenticationType::ANONYMOUS }
 };
 static const int authenticationTypeEnumSize = sizeof(authenticationTypeEnum) / sizeof(*authenticationTypeEnum);
 
-template <typename T>
+template<typename T>
 static typename T::value_type stringToValue(const T *table, const int tableSize, const QString &string)
 {
     const QString ref = string.toLower();
@@ -70,12 +70,12 @@ static typename T::value_type stringToValue(const T *table, const int tableSize,
     return table[0].value; // TODO: error handling
 }
 
-Transport::Transport(const QString &type, QObject *parent) :
-    SetupObject(parent),
-    m_transportId(-1),
-    m_port(-1),
-    m_encr(MailTransport::Transport::EnumEncryption::TLS),
-    m_auth(MailTransport::Transport::EnumAuthenticationType::PLAIN)
+Transport::Transport(const QString &type, QObject *parent)
+    : SetupObject(parent)
+    , m_transportId(-1)
+    , m_port(-1)
+    , m_encr(MailTransport::Transport::EnumEncryption::TLS)
+    , m_auth(MailTransport::Transport::EnumAuthenticationType::PLAIN)
     , m_editMode(false)
 {
     m_transportType = stringToValue(transportTypeEnums, transportTypeEnumsSize, type);
@@ -173,4 +173,3 @@ int Transport::transportId() const
 {
     return m_transportId;
 }
-
